@@ -1,12 +1,26 @@
 (* approx: proxy server for Debian archive files
-   Copyright (C) 2010  Eric C. Cooper <ecc@cmu.edu>
+   Copyright (C) 2011  Eric C. Cooper <ecc@cmu.edu>
    Released under the GNU General Public License *)
 
-open Util
+open Printf
 open Syslog
 
-let facility = facility_of_string Config.syslog
-let log = openlog ~facility (Filename.basename Sys.argv.(0))
+let stderr_log _ msg =
+  prerr_string msg;
+  flush stderr
+
+let writer = ref stderr_log
+
+let log_to_stderr () =
+  writer := stderr_log
+
+let log_to_syslog () =
+  let facility = facility_of_string Config.syslog in
+  let ident =
+    sprintf "%s[%d]" (Filename.basename Sys.argv.(0)) (Unix.getpid ())
+  in
+  let log = openlog ~facility ident in
+  writer := syslog log
 
 let message enabled level =
   (* ensure message is newline-terminated,
@@ -16,7 +30,7 @@ let message enabled level =
     if n = 0 || str.[n - 1] <> '\n' then str ^ "\n"
     else str
   in
-  Printf.ksprintf (fun str -> if enabled then syslog log level (terminate str))
+  ksprintf (fun str -> if enabled then !writer level (terminate str))
 
 let error_message fmt = message true `LOG_ERR fmt
 let info_message fmt = message Config.verbose `LOG_INFO fmt
